@@ -1,6 +1,6 @@
 package Mojo::Webqq;
 use strict;
-$Mojo::Webqq::VERSION = "1.3.4";
+$Mojo::Webqq::VERSION = "1.3.5";
 use Mojo::Base;
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -64,6 +64,8 @@ has is_first_login          => -1;
 has login_state             => "init";
 has poll_failure_count      => 0;
 has poll_failure_count_max  => 3;
+has model_update_failure_count      => 0;
+has model_update_failure_count_max  => 3;
 has message_queue           => sub { $_[0]->gen_message_queue };
 has ua                      => sub {
     local $ENV{MOJO_USERAGENT_DEBUG} = $_[0]->ua_debug;
