@@ -40,24 +40,47 @@ sub run{
 }
 sub stop{
     my $self = shift;
+    my $mode = shift || "auto";
     $self->is_stop(1);
-    $Mojo::Webqq::Client::CLIENT_COUNT > 1?$Mojo::Webqq::Client::CLIENT_COUNT--:exit;
+    if($mode eq "auto"){
+        $Mojo::Webqq::Client::CLIENT_COUNT > 1?$Mojo::Webqq::Client::CLIENT_COUNT--:exit;
+    }
+    else{
+        $Mojo::Webqq::Client::CLIENT_COUNT--;
+    }
+}
+sub exit{
+    my $s = shift;  
+    my $code = shift;
+    exit(defined $code?$code+0:0);
 }
 sub ready{
     my $self = shift;
     $self->set_message_queue();
+    $self->on("model_update_fail"=>sub{
+        my $self = shift;
+        my $last_model_update_failure_count = $self->model_update_failure_count;
+        $self->model_update_failure_count(++$last_model_update_failure_count);  
+        if($self->model_update_failure_count >= $self->model_update_failure_count_max ){
+            $self->model_update_failure_count(0);
+            $self->_relink();
+        }
+    });
     $self->interval(600,sub{
+        return if $self->is_stop;
         $self->update_group;
     });
 
     $self->timer(60,sub{
         $self->interval(600,sub{
+            return if $self->is_stop;
             $self->update_discuss;    
         });
     });
 
     $self->timer(60+60,sub{
         $self->interval(600,sub{
+            return if $self->is_stop;
             $self->update_friend;
         });
     });
